==> dao-2.0.0-alpha.1-sources.jar: org/n52/series/db/dao/GenericDao.java <==
/*
 * Copyright (C) 2015-2017 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public License
 * version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */
package org.n52.series.db.dao;

import java.io.Serializable;
import java.util.List;

import org.n52.series.db.DataAccessException;

/**
 * @param <T> entity type
 * @param <K> primary key
 */
public interface GenericDao<T, K extends Serializable> {

    T getInstance(K key, DbQuery parameters) throws DataAccessException;

    List<T> getAllInstances(DbQuery parameters) throws DataAccessException;

    Integer getCount(DbQuery query) throws DataAccessException;

    boolean hasInstance(Long id, DbQuery query, Class<? extends T> clazz) throws DataAccessException;

}

==> dao-3.0.0-alpha.1-sources.jar: org/n52/series/db/dao/GenericDao.java <==
/*
 * Copyright (C) 2015-2018 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public License
 * version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */
package org.n52.series.db.dao;

import java.io.Serializable;
import java.util.List;

import org.n52.series.db.DataAccessException;

/**
 * @param <T> entity type
 * @param <K> primary key
 */
public interface GenericDao<T, K extends Serializable> {

    T getInstance(K key, DbQuery parameters) throws DataAccessException;

    List<T> getAllInstances(DbQuery parameters) throws DataAccessException;

    Integer getCount(DbQuery query) throws DataAccessException;

    boolean hasInstance(K id, DbQuery query) throws DataAccessException;

}
